@@ -474,7 +474,7 @@ class Eniam():
             opts = {
                 'silent': silent,
             }
-            return pool.map(self._exec_dom, map(lambda sentence: [sentence, opts], input))
+            return pool.map(self._exec_dom_opt, map(lambda sentence: [sentence, opts], input))
         else:
             return self._exec_dom(input, silent)
 
